| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transfer.Types.ListedAgreement
Description
Synopsis
- data ListedAgreement = ListedAgreement' {}
- newListedAgreement :: ListedAgreement
- listedAgreement_agreementId :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_arn :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_description :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_localProfileId :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_partnerProfileId :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_serverId :: Lens' ListedAgreement (Maybe Text)
- listedAgreement_status :: Lens' ListedAgreement (Maybe AgreementStatusType)
Documentation
data ListedAgreement Source #
Describes the properties of an agreement.
See: newListedAgreement smart constructor.
Constructors
| ListedAgreement' | |
Fields
| |
Instances
newListedAgreement :: ListedAgreement Source #
Create a value of ListedAgreement with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:agreementId:ListedAgreement', listedAgreement_agreementId - A unique identifier for the agreement. This identifier is returned when
you create an agreement.
$sel:arn:ListedAgreement', listedAgreement_arn - The Amazon Resource Name (ARN) of the specified agreement.
$sel:description:ListedAgreement', listedAgreement_description - The current description for the agreement. You can change it by calling
the UpdateAgreement operation and providing a new description.
$sel:localProfileId:ListedAgreement', listedAgreement_localProfileId - A unique identifier for the AS2 local profile.
$sel:partnerProfileId:ListedAgreement', listedAgreement_partnerProfileId - A unique identifier for the partner profile.
$sel:serverId:ListedAgreement', listedAgreement_serverId - The unique identifier for the agreement.
$sel:status:ListedAgreement', listedAgreement_status - The agreement can be either ACTIVE or INACTIVE.
listedAgreement_agreementId :: Lens' ListedAgreement (Maybe Text) Source #
A unique identifier for the agreement. This identifier is returned when you create an agreement.
listedAgreement_arn :: Lens' ListedAgreement (Maybe Text) Source #
The Amazon Resource Name (ARN) of the specified agreement.
listedAgreement_description :: Lens' ListedAgreement (Maybe Text) Source #
The current description for the agreement. You can change it by calling
the UpdateAgreement operation and providing a new description.
listedAgreement_localProfileId :: Lens' ListedAgreement (Maybe Text) Source #
A unique identifier for the AS2 local profile.
listedAgreement_partnerProfileId :: Lens' ListedAgreement (Maybe Text) Source #
A unique identifier for the partner profile.
listedAgreement_serverId :: Lens' ListedAgreement (Maybe Text) Source #
The unique identifier for the agreement.
listedAgreement_status :: Lens' ListedAgreement (Maybe AgreementStatusType) Source #
The agreement can be either ACTIVE or INACTIVE.