| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transfer.Types.ListedCertificate
Description
Synopsis
- data ListedCertificate = ListedCertificate' {}
- newListedCertificate :: ListedCertificate
- listedCertificate_activeDate :: Lens' ListedCertificate (Maybe UTCTime)
- listedCertificate_arn :: Lens' ListedCertificate (Maybe Text)
- listedCertificate_certificateId :: Lens' ListedCertificate (Maybe Text)
- listedCertificate_description :: Lens' ListedCertificate (Maybe Text)
- listedCertificate_inactiveDate :: Lens' ListedCertificate (Maybe UTCTime)
- listedCertificate_status :: Lens' ListedCertificate (Maybe CertificateStatusType)
- listedCertificate_type :: Lens' ListedCertificate (Maybe CertificateType)
- listedCertificate_usage :: Lens' ListedCertificate (Maybe CertificateUsageType)
Documentation
data ListedCertificate Source #
Describes the properties of a certificate.
See: newListedCertificate smart constructor.
Constructors
| ListedCertificate' | |
Fields
| |
Instances
newListedCertificate :: ListedCertificate Source #
Create a value of ListedCertificate with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:activeDate:ListedCertificate', listedCertificate_activeDate - An optional date that specifies when the certificate becomes active.
$sel:arn:ListedCertificate', listedCertificate_arn - The Amazon Resource Name (ARN) of the specified certificate.
$sel:certificateId:ListedCertificate', listedCertificate_certificateId - An array of identifiers for the imported certificates. You use this
identifier for working with profiles and partner profiles.
$sel:description:ListedCertificate', listedCertificate_description - The name or short description that's used to identify the certificate.
$sel:inactiveDate:ListedCertificate', listedCertificate_inactiveDate - An optional date that specifies when the certificate becomes inactive.
$sel:status:ListedCertificate', listedCertificate_status - The certificate can be either ACTIVE, PENDING_ROTATION, or
INACTIVE. PENDING_ROTATION means that this certificate will replace
the current certificate when it expires.
$sel:type':ListedCertificate', listedCertificate_type - The type for the certificate. If a private key has been specified for
the certificate, its type is CERTIFICATE_WITH_PRIVATE_KEY. If there is
no private key, the type is CERTIFICATE.
$sel:usage:ListedCertificate', listedCertificate_usage - Specifies whether this certificate is used for signing or encryption.
listedCertificate_activeDate :: Lens' ListedCertificate (Maybe UTCTime) Source #
An optional date that specifies when the certificate becomes active.
listedCertificate_arn :: Lens' ListedCertificate (Maybe Text) Source #
The Amazon Resource Name (ARN) of the specified certificate.
listedCertificate_certificateId :: Lens' ListedCertificate (Maybe Text) Source #
An array of identifiers for the imported certificates. You use this identifier for working with profiles and partner profiles.
listedCertificate_description :: Lens' ListedCertificate (Maybe Text) Source #
The name or short description that's used to identify the certificate.
listedCertificate_inactiveDate :: Lens' ListedCertificate (Maybe UTCTime) Source #
An optional date that specifies when the certificate becomes inactive.
listedCertificate_status :: Lens' ListedCertificate (Maybe CertificateStatusType) Source #
The certificate can be either ACTIVE, PENDING_ROTATION, or
INACTIVE. PENDING_ROTATION means that this certificate will replace
the current certificate when it expires.
listedCertificate_type :: Lens' ListedCertificate (Maybe CertificateType) Source #
The type for the certificate. If a private key has been specified for
the certificate, its type is CERTIFICATE_WITH_PRIVATE_KEY. If there is
no private key, the type is CERTIFICATE.
listedCertificate_usage :: Lens' ListedCertificate (Maybe CertificateUsageType) Source #
Specifies whether this certificate is used for signing or encryption.