| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transfer.Types.ListedExecution
Description
Synopsis
- data ListedExecution = ListedExecution' {}
- newListedExecution :: ListedExecution
- listedExecution_executionId :: Lens' ListedExecution (Maybe Text)
- listedExecution_initialFileLocation :: Lens' ListedExecution (Maybe FileLocation)
- listedExecution_serviceMetadata :: Lens' ListedExecution (Maybe ServiceMetadata)
- listedExecution_status :: Lens' ListedExecution (Maybe ExecutionStatus)
Documentation
data ListedExecution Source #
Returns properties of the execution that is specified.
See: newListedExecution smart constructor.
Constructors
| ListedExecution' | |
Fields
| |
Instances
newListedExecution :: ListedExecution Source #
Create a value of ListedExecution with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:executionId:ListedExecution', listedExecution_executionId - A unique identifier for the execution of a workflow.
$sel:initialFileLocation:ListedExecution', listedExecution_initialFileLocation - A structure that describes the Amazon S3 or EFS file location. This is
the file location when the execution begins: if the file is being
copied, this is the initial (as opposed to destination) file location.
$sel:serviceMetadata:ListedExecution', listedExecution_serviceMetadata - A container object for the session details that are associated with a
workflow.
$sel:status:ListedExecution', listedExecution_status - The status is one of the execution. Can be in progress, completed,
exception encountered, or handling the exception.
listedExecution_executionId :: Lens' ListedExecution (Maybe Text) Source #
A unique identifier for the execution of a workflow.
listedExecution_initialFileLocation :: Lens' ListedExecution (Maybe FileLocation) Source #
A structure that describes the Amazon S3 or EFS file location. This is the file location when the execution begins: if the file is being copied, this is the initial (as opposed to destination) file location.
listedExecution_serviceMetadata :: Lens' ListedExecution (Maybe ServiceMetadata) Source #
A container object for the session details that are associated with a workflow.
listedExecution_status :: Lens' ListedExecution (Maybe ExecutionStatus) Source #
The status is one of the execution. Can be in progress, completed, exception encountered, or handling the exception.