| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Transfer.Types.TagStepDetails
Description
Documentation
data TagStepDetails Source #
Each step type has its own StepDetails structure.
The key/value pairs used to tag a file during the execution of a workflow step.
See: newTagStepDetails smart constructor.
Constructors
| TagStepDetails' | |
Fields
| |
Instances
newTagStepDetails :: TagStepDetails Source #
Create a value of TagStepDetails with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:name:TagStepDetails', tagStepDetails_name - The name of the step, used as an identifier.
$sel:sourceFileLocation:TagStepDetails', tagStepDetails_sourceFileLocation - Specifies which file to use as input to the workflow step: either the
output from the previous step, or the originally uploaded file for the
workflow.
- Enter
${previous.file}to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. - Enter
${original.file}to use the originally-uploaded file location as input for this step.
$sel:tags:TagStepDetails', tagStepDetails_tags - Array that contains from 1 to 10 key/value pairs.
tagStepDetails_name :: Lens' TagStepDetails (Maybe Text) Source #
The name of the step, used as an identifier.
tagStepDetails_sourceFileLocation :: Lens' TagStepDetails (Maybe Text) Source #
Specifies which file to use as input to the workflow step: either the output from the previous step, or the originally uploaded file for the workflow.
- Enter
${previous.file}to use the previous file as the input. In this case, this workflow step uses the output file from the previous workflow step as input. This is the default value. - Enter
${original.file}to use the originally-uploaded file location as input for this step.
tagStepDetails_tags :: Lens' TagStepDetails (Maybe (NonEmpty S3Tag)) Source #
Array that contains from 1 to 10 key/value pairs.